/***********************************************************************************************************************
 *
 * blueMarine Metadata - open source media workflow
 * Copyright (C) 2007-2011 by Tidalwave s.a.s. (http://www.tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://bluemarine.tidalwave.it
 * SCM: https://kenai.com/hg/bluemarine~metadata-src
 *
 **********************************************************************************************************************/
package it.tidalwave.metadata.makernote.provider;

import it.tidalwave.imageio.nef.NikonMakerNote3;
import java.beans.PropertyVetoException;
import java.io.IOException;
import org.openide.filesystems.FileUtil;
import org.openide.loaders.DataObject;
import it.tidalwave.imageio.raw.Directory;
import it.tidalwave.metadata.MetadataItemHolder;
import static it.tidalwave.metadata.Metadata.StorageType.*;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import static org.junit.Assert.*;

/*******************************************************************************
 *
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 ******************************************************************************/
public class Nikon3MakerNoteProviderTest
  {
    private Nikon3MakerNoteProvider makerNoteProvider;
    
    @Before
    public void setUp()
      throws PropertyVetoException, IOException 
      {
        makerNoteProvider = new Nikon3MakerNoteProvider();
      }

    @After
    public void tearDown() 
      {
        makerNoteProvider = null;
      }

    @Test
    public void testGetManagedClass() 
      {
        assertEquals(NikonMakerNote3.class, makerNoteProvider.getItemClass());
      }  

    @Test
    public void testFindMetadataItemFromGoodFile()
      throws Exception
      {
        final DataObject dataObject = DataObject.find(FileUtil.createMemoryFileSystem().getRoot().createData("goodfile"));       
        final MetadataItemHolder<NikonMakerNote3> result = makerNoteProvider.findOrCreateItems(dataObject, EXTERNAL).iterator().next();
        assertNotNull(result);
//        assertTrue(result.isAvailable()); FIXME
      }
    
    @Test
    public void testFindMetadataItemFromBadFile()
      throws Exception
      {
        final DataObject dataObject = DataObject.find(FileUtil.createMemoryFileSystem().getRoot().createData("badfile"));       
        final MetadataItemHolder<NikonMakerNote3> result = makerNoteProvider.findOrCreateItems(dataObject, EXTERNAL).iterator().next();
        assertNotNull(result);
//        assertFalse(result.isAvailable()); FIXME
      }
    
    @Test
    public void testLastestModificationTimeIsUpdated()
      throws Exception
      {
        final DataObject dataObject = DataObject.find(FileUtil.createMemoryFileSystem().getRoot().createData("goodfile"));       
        final MetadataItemHolder<NikonMakerNote3> item = makerNoteProvider.findOrCreateItems(dataObject, EXTERNAL).iterator().next();
        assertNotNull(item);
//        final Date timestamp1 = item.getLatestModificationTime();
//        assertTrue(item.isAvailable()); FIXME
//        
//        Thread.sleep(1000); FIXME
//        final Date now = new Date();
//        item.setArtist("new artist");
//        final Date timestamp2 = item.getLatestModificationTime();
//        assertTrue(timestamp2.getTime() - now.getTime() < 50);
//        assertNotSame(timestamp1, timestamp2);
      }
  }